@@ -2,5 +2,5 @@
 
 namespace wrtr
 {
-    void print(const char* format, ...);
+    void print(const char* message);
 } // namespace wrtr
\ No newline at end of file
